@@ -1,10 +1,11 @@
 from datetime import datetime, timedelta
 
 from sp_api.api import Orders
+from sp_api.base import Marketplaces
 
 
 def test_get_orders():
-    res = Orders().get_orders(CreatedAfter='TEST_CASE_200')
+    res = Orders().get_orders(CreatedAfter='TEST_CASE_200', MarketplaceIds=["ATVPDKIKX0DER"])
     assert res.errors is None
     assert res.payload.get('Orders') is not None
 
@@ -46,3 +47,4 @@ def test_get_orders_400_error():
     except SellingApiBadRequestException as sep:
         assert sep.code == 400
         assert sep.amzn_code == 'InvalidInput'
+
